import{d,ez as b,F as l,a as g,b as f,c as v,w as r,f as s}from"./outputWidgets.b00cf7e9.js";import{B as _}from"./BaseLayout.737caf54.js";import{a as h}from"./asyncComputed.1f0126f2.js";import"./router.7caa92ea.js";import"./jwt-decode.esm.74bd4619.js";import"./index.1aa24eee.js";import{P as z}from"./project.2d9cbf84.js";import{O as y}from"./organization.cd688c81.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.2fa1cf2b.js";import{S as I}from"./Sidebar.b93bfb48.js";import{e as w,L as O,M as C,N as P,O as k,P as B,q as L,Q as $,s as M,G as N,H as S,I as x}from"./icons.99873bd8.js";import"./FormItem.4a1fd62e.js";import"./hasIn.606210e6.js";import"./storage.c80f95dc.js";import"./index.d1e02be5.js";import"./index.cf4c23b9.js";import"./record.2bf8fb00.js";import"./pubsub.b6fbda2c.js";import"./logo.084e5d7c.js";import"./Text.20fe3ce1.js";import"./index.0d76c058.js";import"./index.47033021.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="0670b6bf-ceae-49f1-a2bb-3d100d42cc2c",o._sentryDebugIdIdentifier="sentry-dbid-0670b6bf-ceae-49f1-a2bb-3d100d42cc2c")}catch{}})();const na=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>z.get(c).then(async e=>{const t=await y.get(e.organizationId);return{project:e,organization:t}})),m=l(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=l(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:O},{name:"Connectors",path:"connectors",icon:C,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:P},{name:"API Keys",path:"api-keys",icon:k},{name:"Env Vars",path:"env-vars",icon:B},{name:"Files",path:"files",icon:L},{name:"Logs",icon:$,path:"logs"},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:N,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:S,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:x,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{na as default};
//# sourceMappingURL=Project.71a24271.js.map
