[data-v-c916ecf3]:root{--main-font-family: DM Sans, sans-serif}[data-v-c916ecf3]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-c916ecf3]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-c916ecf3]{background-color:#fff;padding:10px}.p-steps[data-v-c916ecf3]{position:relative;width:100%}.p-steps .p-steps-list[data-v-c916ecf3]{padding:0;margin:0;list-style-type:none;display:flex}.p-steps-item[data-v-c916ecf3]{position:relative;display:flex;justify-content:center;flex:1 1 auto}.p-steps-item .p-menuitem-link[data-v-c916ecf3]{display:inline-flex;flex-direction:column;align-items:center;overflow:hidden;text-decoration:none}.p-steps.p-steps-readonly .p-steps-item[data-v-c916ecf3]{cursor:auto}.p-steps-item.p-steps-current .p-menuitem-link[data-v-c916ecf3]{cursor:default}.p-steps-title[data-v-c916ecf3]{white-space:nowrap}.p-steps-number[data-v-c916ecf3]{display:flex;align-items:center;justify-content:center}.p-steps-title[data-v-c916ecf3]{display:block}.p-steps .p-steps-item .p-menuitem-link[data-v-c916ecf3]{transition:box-shadow .2s;border-radius:6px;z-index:1}.p-steps .p-steps-item .p-menuitem-link .p-steps-number[data-v-c916ecf3]{color:var(--font-color);border:1px solid #e9ecef;background:var(--background-color);min-width:2rem;height:2rem;font-size:1.143rem;z-index:1;border-radius:50%}.p-steps .p-steps-item .p-menuitem-link[data-v-c916ecf3]:not(.p-disabled):focus{outline:0 none;outline-offset:0;box-shadow:0 0 0 .2rem #bfdbfe}.p-steps .p-steps-item.p-highlight .p-steps-number[data-v-c916ecf3]{background:var(--color-main);color:var(--button-font-color-main)}.p-steps .p-steps-item[data-v-c916ecf3]:before{content:" ";border-top:1px solid #dee2e6;width:100%;top:100%;left:0;display:block;position:absolute;margin-top:-1rem}.disabled[data-v-e711f126]{opacity:.5;cursor:not-allowed}
