import{f as a,eE as d,f3 as f}from"./outputWidgets.b00cf7e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="2a18368a-60d0-47c2-89d6-2bf65e136a4d",e._sentryDebugIdIdentifier="sentry-dbid-2a18368a-60d0-47c2-89d6-2bf65e136a4d")}catch{}})();function c(e){for(var r=1;r<arguments.length;r++){var t=arguments[r]!=null?Object(arguments[r]):{},n=Object.keys(t);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(t).filter(function(i){return Object.getOwnPropertyDescriptor(t,i).enumerable}))),n.forEach(function(i){o(e,i,t[i])})}return e}function o(e,r,t){return r in e?Object.defineProperty(e,r,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[r]=t,e}var l=function(r,t){var n=c({},r,t.attrs);return a(d,c({},n,{icon:f}),null)};l.displayName="CheckCircleFilled";l.inheritAttrs=!1;const s=l;export{s as C};
//# sourceMappingURL=CheckCircleFilled.06dc886b.js.map
