import{a as e,A as t,B as i}from"./Text.20fe3ce1.js";import{A as o}from"./Link.29c2dd22.js";import{a as r,A as f}from"./Title.334eceae.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="3ffad98f-1a04-4092-9721-c5fcc609087f",n._sentryDebugIdIdentifier="sentry-dbid-3ffad98f-1a04-4092-9721-c5fcc609087f")}catch{}})();e.Text=t;e.Title=r;e.Paragraph=f;e.Link=o;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,t),n.component(e.Title.displayName,r),n.component(e.Paragraph.displayName,f),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.77ec4d5c.js.map
