import{t as n,b as s,et as a}from"./outputWidgets.b00cf7e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a89ebb22-67ad-4ad9-9f63-d36c3018a491",e._sentryDebugIdIdentifier="sentry-dbid-a89ebb22-67ad-4ad9-9f63-d36c3018a491")}catch{}})();const d={},o={class:"organization-settings"};function r(e,t){return s(),a("div",o,"Organization settings")}const f=n(d,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.bbc63c28.js.map
