import"./outputWidgets.b00cf7e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="719ad1e0-4ae8-471b-9bfe-6a585aa9fc21",e._sentryDebugIdIdentifier="sentry-dbid-719ad1e0-4ae8-471b-9bfe-6a585aa9fc21")}catch{}})();function l(e,a,r=!1,t=!0){const n=(t?e.toLocaleLowerCase():e).replace(/[^a-zA-Z0-9]/g,"_"),c=r?n:n.replace(/_+/g,"_");return a?c:c.replace(/_$/,"")}function d(e){var n;const r=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,o=r.match(t);return(n=o==null?void 0:o.join("-"))!=null?n:""}export{d as a,l as n};
//# sourceMappingURL=string.25d774c9.js.map
