var o=Object.defineProperty;var i=(t,e,a)=>e in t?o(t,e,{enumerable:!0,configurable:!0,writable:!0,value:a}):t[e]=a;var n=(t,e,a)=>(i(t,typeof e!="symbol"?e+"":e,a),a);import{g as c,h as f,_ as u}from"./outputWidgets.b00cf7e9.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="3505f16a-c98c-4e55-9682-e47910f429a5",t._sentryDebugIdIdentifier="sentry-dbid-3505f16a-c98c-4e55-9682-e47910f429a5")}catch{}})();const d=[{path:"/:path(.*)*",name:"player",component:()=>u(()=>import("./Player.65f570b8.js"),["assets/Player.65f570b8.js","assets/FormRunner.7f674642.js","assets/outputWidgets.b00cf7e9.js","assets/outputWidgets.3c848cd5.css","assets/url.255821a6.js","assets/storage.c80f95dc.js","assets/pubsub.b6fbda2c.js","assets/jwt-decode.esm.74bd4619.js","assets/icons.99873bd8.js","assets/CircularLoading.432b1cc5.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.d681aae7.js","assets/PlayerNavbar.d1d85d81.css","assets/ActionButton.5120a9f7.js","assets/ActionButton.f74e60ec.css","assets/WidgetsFrame.7d0e2ff8.js","assets/WidgetsFrame.97ae601d.css","assets/index.d039227c.js","assets/Card.7dd73857.js","assets/TabPane.42b37be1.js","assets/hasIn.606210e6.js","assets/index.77ec4d5c.js","assets/Text.20fe3ce1.js","assets/Link.29c2dd22.js","assets/Title.334eceae.js","assets/FormRunner.8ff3f1ac.css","assets/uuid.564748f2.js","assets/asyncComputed.1f0126f2.js","assets/Player.6fed9080.css"])}],g=c({history:f("/"),routes:d,scrollBehavior(t){if(t.hash)return{el:t.hash}}});async function w(){const t=await fetch("/_settings");if(!t.ok)throw new Error(await t.text());const e=await t.json();await r.init(e)}const s=class{constructor(e){this.config=e}static async init(e){s.instance=new s(e)}get showWatermark(){return this.config.show_watermark}get isStagingRelease(){return{}.VITE_ABSTRA_RELEASE==="staging"}get isLocal(){return location.origin.match(/http:\/\/localhost:\d+/)}};let r=s;n(r,"instance",null);export{r as S,g as a,d as r,w as s};
//# sourceMappingURL=index.24187c91.js.map
