import{d as m,ez as c,u as e,b as p,c as u,et as y,f as a,w as o,be as _,ao as d,ev as g,e as b,eB as x}from"./outputWidgets.b00cf7e9.js";import"./router.7caa92ea.js";import"./jwt-decode.esm.74bd4619.js";import"./index.1aa24eee.js";import{O as w}from"./organization.cd688c81.js";import{a as h}from"./asyncComputed.1f0126f2.js";import{a as k}from"./Title.334eceae.js";import{A as B}from"./index.4b86cc41.js";import{A}from"./index.0f5e3d3d.js";import{A as C}from"./Text.20fe3ce1.js";import{C as I}from"./Card.7dd73857.js";import"./FormItem.4a1fd62e.js";import"./hasIn.606210e6.js";import"./storage.c80f95dc.js";import"./index.d1e02be5.js";import"./index.cf4c23b9.js";import"./record.2bf8fb00.js";import"./pubsub.b6fbda2c.js";import"./TabPane.42b37be1.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="bc1209bf-b7f1-4219-a73e-eae537143da7",t._sentryDebugIdIdentifier="sentry-dbid-bc1209bf-b7f1-4219-a73e-eae537143da7")}catch{}})();const v={key:1},z={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},X=m({__name:"Billing",setup(t){const n=c().params.organizationId,{loading:l,result:f}=h(()=>w.get(n));return(D,T)=>e(l)?(p(),u(e(_),{key:0})):(p(),y("div",v,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(k),{level:3},{default:o(()=>[d("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(A),{style:{"margin-top":"0"}}),a(e(I),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[d("Plan")]),_:1}),b("div",z,x((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{X as default};
//# sourceMappingURL=Billing.1a2a86ee.js.map
